import { FC } from "react"

interface AnalogClockProps {
  time: Date
}

const AnalogClock: FC<AnalogClockProps> = ({ time }) => {
  const hours = time.getHours() % 12
  const minutes = time.getMinutes()
  const seconds = time.getSeconds()

  return (
    <div className="w-32 h-32 relative">
      {/* 刻度 */}
      {Array.from({ length: 60 }).map((_, i) => (
        <div
          key={i}
          className={`absolute left-1/2 top-1/2 -translate-x-1/2 -translate-y-1/2 origin-center ${
            i % 5 === 0 ? "h-2 w-px bg-gray-300" : "h-1 w-px bg-gray-500"
          }`}
          style={{
            transform: `rotate(${i * 6}deg) translateY(-55px)`,
          }}
        />
      ))}

      {/* 指针 */}
      <div
        className="absolute left-1/2 bottom-1/2 bg-gray-300 w-0.5 h-8 -ml-px origin-bottom"
        style={{ transform: `rotate(${hours * 30 + minutes * 0.5}deg)` }}
      />
      <div
        className="absolute left-1/2 bottom-1/2 bg-gray-300 w-0.5 h-10 -ml-px origin-bottom"
        style={{ transform: `rotate(${minutes * 6}deg)` }}
      />
      <div
        className="absolute left-1/2 bottom-1/2 bg-gray-400 w-px h-12 -ml-px origin-bottom"
        style={{ transform: `rotate(${seconds * 6}deg)` }}
      />

      {/* 中心点 */}
      <div className="absolute left-1/2 top-1/2 w-1.5 h-1.5 bg-gray-300 rounded-full -translate-x-1/2 -translate-y-1/2" />
    </div>
  )
}

export default AnalogClock